﻿* Encoding: UTF-8.
*=========================================================================*
* ENCUESTA DE EDIFICACIONES PERMISOS DE CONSTRUCCIÓN - 2020.
*=========================================================================*

*=========================================================================*
1.  ENCABEZADO DE SINTAXIS
*=========================================================================*

* TÍTULO DE LA SINTAXIS:
* Cálculo de indicadores ENED2020

* OPERACIÓN ESTADÍSTICA:
* Encuesta de edificaciones- Permisos de construcción

* ENTIDAD EJECUTORA:
* Instituto Nacional de Estadística y Censos (INEC)

* DIRECCIÓN TÉCNICA RESPONSABLE:
* Dirección de Estadísticas Económicas (DECON)

********************************************************************************************************
* Fecha de elaboración:        30 de agosto del 2021
* Fecha última modificación:  22 de septiembre del 2021
********************************************************************************************************
*Software estadístico: SPSS 21
********************************************************************************************************
*Elaborado por:
* Unidad de Gestión de Estadísticas Estructurales (GESE).
* Lorena Ramos.
* Jonathan Quijia
********************************************************************************************************
* Revisado por:
* Roberto Chaves
* Jefe de Gestión de Estadísticas Estructurales (GESE)
* Instituto Nacional de Estadística y Censos
* 
********************************************************************************************************
* Aprobado por: 
* Darío Vélez 
* Director de Estadísticas Económicas (DECON)
* Instituto Nacional de Estadística y Censos 
*dario_velez@inec.gob.ec 
********************************************************************************************************
*Instrucciones:
 *1.- Descargar la base de datos de Encuesta de Edificaciones "2020_EDIFICACIONES_BDD.sav " en formato SPSS de la página web del INEC (https://www.ecuadorencifras.gob.ec/edificaciones/).
 *2.- Guardar y abrir la base de datos "2020_EDIFICACIONES_BDD.sav "
 *3.- En el disco C: de su computadora, crear una carpeta llamada "Tabulados ENED". En esta carpeta se exportarán los resultados de los indicadores. 


*=========================================================================*
*2.  CÓDIGO DE LA SINTAXIS
*=========================================================================*

*Ingreso de la población proyectada 2020.

NUMERIC POBLACION (f10.0).
IF(codprovf="01") POBLACION =  881394.
IF(codprovf="02") POBLACION =  209933.
IF(codprovf="03") POBLACION =  281396.
IF(codprovf="04") POBLACION =  186869.
IF(codprovf="05") POBLACION =  488716.
IF(codprovf="06") POBLACION =  524004.
IF(codprovf="07") POBLACION =  715751.
IF(codprovf="08") POBLACION =  643654.
IF(codprovf="09") POBLACION =  4387434.
IF(codprovf="10") POBLACION =  476257.
IF(codprovf="11") POBLACION =  521154.
IF(codprovf="12") POBLACION =  921763.
IF(codprovf="13") POBLACION =  1562079.
IF(codprovf="14") POBLACION =  196535.
IF(codprovf="15") POBLACION =  133705.
IF(codprovf="16") POBLACION =  114202.
IF(codprovf="17") POBLACION =  3228233.
IF(codprovf="18") POBLACION =  590600.
IF(codprovf="19") POBLACION =  120416.
IF(codprovf="20") POBLACION =  33042.
IF(codprovf="21") POBLACION =  230503.
IF(codprovf="22") POBLACION =  161338.
IF(codprovf="23") POBLACION =  458580.
IF(codprovf="24") POBLACION =  401178.
IF(codprovf="90") POBLACION =  41907.
EXECUTE.
VARIABLE LABELS POBLACION 'Población proyectada 2020'.

*===================================================*
* INDICADOR 1: Viviendas a construir por cada 10.000 habitantes
*===================================================*
***Cálculo del indicador***. 

NUMERIC   viv_10000hab (f10).
compute viv_10000hab=(CNUVICAL)/POBLACION*10000.
EXECUTE   .
VARIABLE LABELS   viv_10000hab 'Viviendas a construir por cada 10000 habitantes'. 

***Agregar el indicador calculado según provincia**.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=codprovf
  /viv_10000hab_agre=sum(viv_10000hab).

COMPUTE viv_10000hab= viv_10000hab_agre.
EXECUTE.
DELETE VARIABLES viv_10000hab_agre. 

***Generar tablas y exportar ***

***CUADRO F1***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf viv_10000hab CNUVICAL POBLACION DISPLAY=BOTH
  /TABLE codprovf [C] BY CNUVICAL [S][SUM] + POBLACION [S][MEAN] + viv_10000hab [S][MEAN] 
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=EXCLUDE  TOTAL=YES
  /TITLES
    TITLE='Viviendas a construir por cada 10.000 habitantes, por provincias, año 2020'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2020'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ENED\2020_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F1'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *. 

DATASET CLOSE 2020_EDIFICACIONES_BDD.
*===================================================*
* INDICADOR 2: Promedio de metros cuadrados de construcción por vivienda
*===================================================*

* Se filtra la base de datos de manera que se considera únicamente a las nuevas construcciones para uso residencial.

USE ALL.
COMPUTE filterCARES_$=(CTIPOBR=1 & CARES>0 & CNUVICAL>0).
VARIABLE LABELS filterCARES_$ 'CTIPOBR=1'.
VALUE LABELS filterCARES_$ 0 'Not Selected' 1 'Selected'.
FORMATS filterCARES_$ (f1.0).
FILTER BY filterCARES_$.
EXECUTE. 

***Cálculo del indicador***.

compute Area_viv=CARES/CNUVICAL.
EXECUTE.

***Generar tablas y exportar ***.

***CUADRO N° F2***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf  Area_viv DISPLAY=LABEL
  /TABLE codprovf [C] BY Area_viv [S][MEAN]
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Promedio de metros cuadrados de construcción por vivienda, por provincias, año 2020'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2020'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ENED\2020_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F2'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.

FILTER OFF.
DELETE VARIABLES Area_viv. 
DATASET CLOSE 2020_EDIFICACIONES_BDD.

*===================================================*
* INDICADOR 3: Costo de construcción proyectado por metro cuadrado,
*===================================================*

***Cálculo del indicador ***.

compute VALOR_PROMEDIO=CVAE/CARCO.
execute.
formats VALOR_PROMEDIO (f15.0).
var label VALOR_PROMEDIO 'VALOR PROMEDIO DE LA EDIFICACIÓN'. 
FREQUENCIES VALOR_PROMEDIO.

***Generar tablas y exportar ***

***C-F3***.

* Tablas personalizadas.

CTABLES
  /VLABELS VARIABLES=cdispusx codprovf VALOR_PROMEDIO DISPLAY=LABEL
  /TABLE cdispusx BY codprovf [C] > VALOR_PROMEDIO [S][MEAN]
  /CATEGORIES VARIABLES=cdispusx codprovf ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES
  /TITLES
    TITLE='Costo de construcción proyectado por metro cuadrado, por provincias y uso de la edificación, año 2020'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2020'.


OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ENED\2020_INDICADORES '
     OPERATION=CREATESHEET  SHEET='C-F3'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.


*===================================================*
* INDICADOR 4: Metros cuadrados a construir por cada 100 habitantes
*===================================================*

***Cálculo del indicador ***.

compute m2_100hab=(CARES)/POBLACION*100.
EXECUTE.
VARIABLE LABELS m2_100hab 'Metros cuadrados a construir por 100 habitantes'.

***Agregar el indicador calculado según provincia**.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=codprovf
  /m2_100hab_agre=sum(m2_100hab).

COMPUTE m2_100hab= m2_100hab_agre.
EXECUTE.
DELETE VARIABLES m2_100hab_agre.

***Generar tablas y exportar ***

***C-F4***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf m2_100hab CARES POBLACION DISPLAY=BOTH
  /TABLE codprovf [C] BY CARES [S][SUM] + POBLACION [S][MEAN] + m2_100hab [S][MEAN] 
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES
  /TITLES
    TITLE='Metros cuadrados a construir por cada 100 habitantes, por provincias, año 2020'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2020'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ENED\2020_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F4'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.

DATASET CLOSE 2020_EDIFICACIONES_BDD.



